@@ -1,6 +1,12 @@
 #!/bin/bash
+# shellcheck shell=bash
+
+# shellcheck disable=SC2034
 CONTROLMODE=true
+
+# shellcheck source=base.sh
 . "$TESTLIBPATH/base.sh" || exit 137
+# shellcheck source=random.sh
 . "$TESTLIBPATH/random.sh" || exit 137
 
 maildomain_name_randomname () { #Generates a random string as maildomain an echoes it. Usage: MAILDOMAINNAME=$(maildomain_name_randomname)
@@ -18,7 +24,6 @@ create_mail_domain () { #Creates a mail/domain name like the first argument, sup
 		--position="cn=domain,cn=mail,$ldap_base" \
 		--set name="$domain" \
 		"$@"
-	return $?
 }
 
 delete_mail_domain () { # Deletes a mail/domain name like the first argument, supplied to the function.
@@ -27,7 +32,6 @@ delete_mail_domain () { # Deletes a mail/domain name like the first argument, su
 	# create_mail_domain "$MAILDOMAINNAME"
 	local domain="${1:?mail domain, e.g. \$(maildomain_name_randomname)}"
 	udm-test mail/domain remove --dn "cn=$domain,cn=domain,cn=mail,$ldap_base"
-	return $?
 }
 
 # vim:set filetype=sh ts=4:
